==> chezmoi-2.1.4.tar.gz: chezmoi-2.1.4/internal/chezmoi/debugencryption.go <==
package chezmoi

import (
	"github.com/rs/zerolog/log"

	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
)

// A DebugEncryption logs all calls to an Encryption.
type DebugEncryption struct {
	encryption Encryption
}

// NewDebugEncryption returns a new DebugEncryption.
func NewDebugEncryption(encryption Encryption) *DebugEncryption {
	return &DebugEncryption{
		encryption: encryption,
	}
}

// Decrypt implements Encryption.Decrypt.
func (e *DebugEncryption) Decrypt(ciphertext []byte) ([]byte, error) {
	plaintext, err := e.encryption.Decrypt(ciphertext)
	log.Debug().
		Bytes("ciphertext", chezmoilog.FirstFewBytes(ciphertext)).
		Err(err).
		Bytes("plaintext", chezmoilog.FirstFewBytes(plaintext)).
		Msg("Decrypt")
	return plaintext, err
}

// DecryptToFile implements Encryption.DecryptToFile.
func (e *DebugEncryption) DecryptToFile(plaintextFilename string, ciphertext []byte) error {
	err := e.encryption.DecryptToFile(plaintextFilename, ciphertext)
	log.Debug().
		Str("plaintextFilename", plaintextFilename).
		Bytes("ciphertext", chezmoilog.FirstFewBytes(ciphertext)).
		Err(err).
		Msg("DecryptToFile")
	return err
}

// Encrypt implements Encryption.Encrypt.
func (e *DebugEncryption) Encrypt(plaintext []byte) ([]byte, error) {
	ciphertext, err := e.encryption.Encrypt(plaintext)
	log.Debug().
		Bytes("plaintext", chezmoilog.FirstFewBytes(plaintext)).
		Err(err).
		Bytes("ciphertext", chezmoilog.FirstFewBytes(ciphertext)).
		Msg("Encrypt")
	return ciphertext, err
}

// EncryptFile implements Encryption.EncryptFile.
func (e *DebugEncryption) EncryptFile(plaintextFilename string) ([]byte, error) {
	ciphertext, err := e.encryption.EncryptFile(plaintextFilename)
	log.Debug().
		Str("plaintextFilename", plaintextFilename).
		Err(err).
		Bytes("ciphertext", chezmoilog.FirstFewBytes(ciphertext)).
		Msg("EncryptFile")
	return ciphertext, err
}

// EncryptedSuffix implements Encryption.EncryptedSuffix.
func (e *DebugEncryption) EncryptedSuffix() string {
	return e.encryption.EncryptedSuffix()
}

==> chezmoi-2.5.0.tar.gz: chezmoi-2.5.0/internal/chezmoi/debugencryption.go <==
package chezmoi

import (
	"github.com/rs/zerolog/log"

	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
)

// A DebugEncryption logs all calls to an Encryption.
type DebugEncryption struct {
	encryption Encryption
}

// NewDebugEncryption returns a new DebugEncryption.
func NewDebugEncryption(encryption Encryption) *DebugEncryption {
	return &DebugEncryption{
		encryption: encryption,
	}
}

// Decrypt implements Encryption.Decrypt.
func (e *DebugEncryption) Decrypt(ciphertext []byte) ([]byte, error) {
	plaintext, err := e.encryption.Decrypt(ciphertext)
	log.Debug().
		Bytes("ciphertext", chezmoilog.FirstFewBytes(ciphertext)).
		Err(err).
		Bytes("plaintext", chezmoilog.FirstFewBytes(plaintext)).
		Msg("Decrypt")
	return plaintext, err
}

// DecryptToFile implements Encryption.DecryptToFile.
func (e *DebugEncryption) DecryptToFile(plaintextAbsPath AbsPath, ciphertext []byte) error {
	err := e.encryption.DecryptToFile(plaintextAbsPath, ciphertext)
	log.Debug().
		Str("plaintextAbsPath", string(plaintextAbsPath)).
		Bytes("ciphertext", chezmoilog.FirstFewBytes(ciphertext)).
		Err(err).
		Msg("DecryptToFile")
	return err
}

// Encrypt implements Encryption.Encrypt.
func (e *DebugEncryption) Encrypt(plaintext []byte) ([]byte, error) {
	ciphertext, err := e.encryption.Encrypt(plaintext)
	log.Debug().
		Bytes("plaintext", chezmoilog.FirstFewBytes(plaintext)).
		Err(err).
		Bytes("ciphertext", chezmoilog.FirstFewBytes(ciphertext)).
		Msg("Encrypt")
	return ciphertext, err
}

// EncryptFile implements Encryption.EncryptFile.
func (e *DebugEncryption) EncryptFile(plaintextAbsPath AbsPath) ([]byte, error) {
	ciphertext, err := e.encryption.EncryptFile(plaintextAbsPath)
	log.Debug().
		Str("plaintextAbsPath", string(plaintextAbsPath)).
		Err(err).
		Bytes("ciphertext", chezmoilog.FirstFewBytes(ciphertext)).
		Msg("EncryptFile")
	return ciphertext, err
}

// EncryptedSuffix implements Encryption.EncryptedSuffix.
func (e *DebugEncryption) EncryptedSuffix() string {
	return e.encryption.EncryptedSuffix()
}
